<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="es">
<context>
    <name>QAccel</name>
    <message>
        <source>Space</source>
        <translation>Espacio</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>Backtab</source>
        <translation>Retro Tab</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>Retroceso</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Retorno</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Ins</source>
        <translation>Ins</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Supr</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>SysReq</source>
        <translation>Pet Sis</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Iztquierda</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>Re Pag</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>Av Pag</translation>
    </message>
    <message>
        <source>CapsLock</source>
        <translation>Bloq Mayús</translation>
    </message>
    <message>
        <source>NumLock</source>
        <translation>Bloq Num</translation>
    </message>
    <message>
        <source>ScrollLock</source>
        <translation>Block Despl</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>F%1</source>
        <translation>F%1</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menú</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Adelante</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>Volume Down</source>
        <translation>Bajar Volumen</translation>
    </message>
    <message>
        <source>Volume Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Volume Up</source>
        <translation>Subir Volumen</translation>
    </message>
    <message>
        <source>Bass Boost</source>
        <translation>Potenciar Graves</translation>
    </message>
    <message>
        <source>Bass Up</source>
        <translation>Subir Graves</translation>
    </message>
    <message>
        <source>Bass Down</source>
        <translation>Bajar Graves</translation>
    </message>
    <message>
        <source>Treble Up</source>
        <translation>Subir Agudos</translation>
    </message>
    <message>
        <source>Treble Down</source>
        <translation>Bajar Agudos</translation>
    </message>
    <message>
        <source>Media Play</source>
        <translation>Comenzar Media</translation>
    </message>
    <message>
        <source>Media Stop</source>
        <translation>Parar Media</translation>
    </message>
    <message>
        <source>Media Previous</source>
        <translation>Media Anterior</translation>
    </message>
    <message>
        <source>Media Next</source>
        <translation>Media Siguiente</translation>
    </message>
    <message>
        <source>Media Record</source>
        <translation>Grabar Media</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Standby</source>
        <translation>Reposo</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Abrir URL</translation>
    </message>
    <message>
        <source>Launch Mail</source>
        <translation>Lanzar Correo</translation>
    </message>
    <message>
        <source>Launch Media</source>
        <translation>Lanzar Media</translation>
    </message>
    <message>
        <source>Launch (0)</source>
        <translation>Lanzar (0)</translation>
    </message>
    <message>
        <source>Launch (1)</source>
        <translation>Lanzar (1)</translation>
    </message>
    <message>
        <source>Launch (2)</source>
        <translation>Lanzar (2)</translation>
    </message>
    <message>
        <source>Launch (3)</source>
        <translation>Lanzar (3)</translation>
    </message>
    <message>
        <source>Launch (4)</source>
        <translation>Lanzar (4)</translation>
    </message>
    <message>
        <source>Launch (5)</source>
        <translation>Lanzar (5)</translation>
    </message>
    <message>
        <source>Launch (6)</source>
        <translation>Lanzar (6)</translation>
    </message>
    <message>
        <source>Launch (7)</source>
        <translation>Lanzar (7)</translation>
    </message>
    <message>
        <source>Launch (8)</source>
        <translation>Lanzar (8)</translation>
    </message>
    <message>
        <source>Launch (9)</source>
        <translation>Lanzar (9)</translation>
    </message>
    <message>
        <source>Launch (A)</source>
        <translation>Lanzar (A)</translation>
    </message>
    <message>
        <source>Launch (B)</source>
        <translation>Lanzar (B)</translation>
    </message>
    <message>
        <source>Launch (C)</source>
        <translation>Lanzar (C)</translation>
    </message>
    <message>
        <source>Launch (D)</source>
        <translation>Lanzar (D)</translation>
    </message>
    <message>
        <source>Launch (E)</source>
        <translation>Lanzar (E)</translation>
    </message>
    <message>
        <source>Launch (F)</source>
        <translation>Lanzar (F)</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>QT_LAYOUT_DIRECTION</source>
        <comment>Translate this string to the string &apos;LTR&apos; in left-to-right languages or to &apos;RTL&apos; in right-to-left languages (such as Hebrew and Arabic) to get proper widget layout.</comment>
        <translation>LTR</translation>
    </message>
    <message>
        <source>Executable &apos;%1&apos; requires TQt %2, found TQt %3.</source>
        <translation>El programa &apos;%1&apos; requiere TQt %2, se encontró TQt %3.</translation>
    </message>
    <message>
        <source>Incompatible TQt Library Error</source>
        <translation>Error: Biblioteca TQt incompatible</translation>
    </message>
</context>
<context>
    <name>QAquaStyle</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>QColorDialog</name>
    <message>
        <source>Hu&amp;e:</source>
        <translation>&amp;Tono:</translation>
    </message>
    <message>
        <source>&amp;Sat:</source>
        <translation>&amp;Sat:</translation>
    </message>
    <message>
        <source>&amp;Val:</source>
        <translation>&amp;Val:</translation>
    </message>
    <message>
        <source>&amp;Red:</source>
        <translation>&amp;Rojo:</translation>
    </message>
    <message>
        <source>&amp;Green:</source>
        <translation>V&amp;erde:</translation>
    </message>
    <message>
        <source>Bl&amp;ue:</source>
        <translation>Az&amp;ul:</translation>
    </message>
    <message>
        <source>A&amp;lpha channel:</source>
        <translation>Canal A&amp;lfa:</translation>
    </message>
    <message>
        <source>&amp;Basic colors</source>
        <translation>Colores &amp;básicos</translation>
    </message>
    <message>
        <source>&amp;Custom colors</source>
        <translation>&amp;Colores personalizados</translation>
    </message>
    <message>
        <source>&amp;Define Custom Colors &gt;&gt;</source>
        <translation>&amp;Definir Colores Personalizados &gt;&gt;</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>&amp;Add to Custom Colors</source>
        <translation>&amp;Añadir a Colores Personalizados</translation>
    </message>
    <message>
        <source>Select color</source>
        <translation>Seleccionar Color</translation>
    </message>
</context>
<context>
    <name>QDataTable</name>
    <message>
        <source>True</source>
        <translation>Verdadero</translation>
    </message>
    <message>
        <source>False</source>
        <translation>Falso</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insertar</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>QDialog</name>
    <message>
        <source>What&apos;s This?</source>
        <translation>¿Qué es ésto?</translation>
    </message>
</context>
<context>
    <name>QErrorMessage</name>
    <message>
        <source>&amp;Show this message again</source>
        <translation>Mostrar e&amp;ste mensaje otra vez</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Debug Message:</source>
        <translation>Mensaje de depuración:</translation>
    </message>
    <message>
        <source>Warning:</source>
        <translation>Aviso:</translation>
    </message>
    <message>
        <source>Fatal Error:</source>
        <translation>Error fatal:</translation>
    </message>
</context>
<context>
    <name>QFileDialog</name>
    <message>
        <source>Copy or Move a File</source>
        <translation>Copiar o Mover un Fichero</translation>
    </message>
    <message>
        <source>Read: %1</source>
        <translation>Leer: %1</translation>
    </message>
    <message>
        <source>Write: %1</source>
        <translation>Escribir: %1</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Todos los ficheros (*)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Attributes</source>
        <translation>Atributos</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Look &amp;in:</source>
        <translation>Buscar &amp;en:</translation>
    </message>
    <message>
        <source>File &amp;name:</source>
        <translation>&amp;Nombre de fichero:</translation>
    </message>
    <message>
        <source>File &amp;type:</source>
        <translation>&amp;Tipo de fichero:</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>One directory up</source>
        <translation>Directorio superior</translation>
    </message>
    <message>
        <source>Create New Folder</source>
        <translation>Crear nueva carpeta</translation>
    </message>
    <message>
        <source>List View</source>
        <translation>Vista de lista</translation>
    </message>
    <message>
        <source>Detail View</source>
        <translation>Vista detallada</translation>
    </message>
    <message>
        <source>Preview File Info</source>
        <translation>Ver Info del fichero</translation>
    </message>
    <message>
        <source>Preview File Contents</source>
        <translation>Ver Contenido del fichero</translation>
    </message>
    <message>
        <source>Read-write</source>
        <translation>Lectura-escritura</translation>
    </message>
    <message>
        <source>Read-only</source>
        <translation>Sólo lectura</translation>
    </message>
    <message>
        <source>Write-only</source>
        <translation>Sólo escritura</translation>
    </message>
    <message>
        <source>Inaccessible</source>
        <translation>Inaccesible</translation>
    </message>
    <message>
        <source>Symlink to File</source>
        <translation>Enlace simbólico a fichero</translation>
    </message>
    <message>
        <source>Symlink to Directory</source>
        <translation>Enlace simbólico a directorio</translation>
    </message>
    <message>
        <source>Symlink to Special</source>
        <translation>Enlace simbólico a especial</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fichero</translation>
    </message>
    <message>
        <source>Dir</source>
        <translation>Dir</translation>
    </message>
    <message>
        <source>Special</source>
        <translation>Especial</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Guardar como</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Renombrar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <source>R&amp;eload</source>
        <translation>R&amp;ecargar</translation>
    </message>
    <message>
        <source>Sort by &amp;Name</source>
        <translation>Ordenar por &amp;Nombre</translation>
    </message>
    <message>
        <source>Sort by &amp;Size</source>
        <translation>Ordenar por &amp;Tamaño</translation>
    </message>
    <message>
        <source>Sort by &amp;Date</source>
        <translation>Ordenar por &amp;Fecha</translation>
    </message>
    <message>
        <source>&amp;Unsorted</source>
        <translation>&amp;Sin orden</translation>
    </message>
    <message>
        <source>Sort</source>
        <translation>Ordenar</translation>
    </message>
    <message>
        <source>Show &amp;hidden files</source>
        <translation>Mostrar fic&amp;heros ocultos</translation>
    </message>
    <message>
        <source>the file</source>
        <translation>el fichero</translation>
    </message>
    <message>
        <source>the directory</source>
        <translation>el directorio</translation>
    </message>
    <message>
        <source>the symlink</source>
        <translation>el enlace simbólico</translation>
    </message>
    <message>
        <source>Delete %1</source>
        <translation>Borrar %1</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Are you sure you wish to delete %1 &quot;%2&quot;?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;¿Estás seguro de querer borrar %1 &quot;%2&quot;?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Sí</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <source>New Folder 1</source>
        <translation>Nueva carpeta 1</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nueva carpeta</translation>
    </message>
    <message>
        <source>New Folder %1</source>
        <translation>Nueva carpeta %1</translation>
    </message>
    <message>
        <source>Find Directory</source>
        <translation>Buscar Directorio</translation>
    </message>
    <message>
        <source>Directories</source>
        <translation>Directorios</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>%1
File not found.
Check path and filename.</source>
        <translation>%1
Fichero no encontrado.
Comprueba la ruta y el nombre del fichero.</translation>
    </message>
    <message>
        <source>All Files (*.*)</source>
        <translation>Todos los ficheros (*.*)</translation>
    </message>
    <message>
        <source>Open </source>
        <translation>Abrir </translation>
    </message>
    <message>
        <source>Select a Directory</source>
        <translation>Seleccione un Directorio</translation>
    </message>
    <message>
        <source>Directory:</source>
        <translation>Directorio:</translation>
    </message>
</context>
<context>
    <name>QFont</name>
    <message>
        <source>Latin</source>
        <translation>Latín</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation>Griego</translation>
    </message>
    <message>
        <source>Cyrillic</source>
        <translation>Cirílico</translation>
    </message>
    <message>
        <source>Armenian</source>
        <translation>Armenio</translation>
    </message>
    <message>
        <source>Georgian</source>
        <translation>Georgiano</translation>
    </message>
    <message>
        <source>Runic</source>
        <translation>Rúnico</translation>
    </message>
    <message>
        <source>Ogham</source>
        <translation>Ogham</translation>
    </message>
    <message>
        <source>Hebrew</source>
        <translation>Hebreo</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>Árabe</translation>
    </message>
    <message>
        <source>Syriac</source>
        <translation>Syriac</translation>
    </message>
    <message>
        <source>Thaana</source>
        <translation>Thaana</translation>
    </message>
    <message>
        <source>Devanagari</source>
        <translation>Devanagari</translation>
    </message>
    <message>
        <source>Bengali</source>
        <translation>Bengalí</translation>
    </message>
    <message>
        <source>Gurmukhi</source>
        <translation>Gurmukhi</translation>
    </message>
    <message>
        <source>Gujarati</source>
        <translation>Gujarati</translation>
    </message>
    <message>
        <source>Oriya</source>
        <translation>Oriya</translation>
    </message>
    <message>
        <source>Tamil</source>
        <translation>Tamil</translation>
    </message>
    <message>
        <source>Telugu</source>
        <translation>Telugu</translation>
    </message>
    <message>
        <source>Kannada</source>
        <translation>Kanada</translation>
    </message>
    <message>
        <source>Malayalam</source>
        <translation>Malayalam</translation>
    </message>
    <message>
        <source>Sinhala</source>
        <translation>Sinhala</translation>
    </message>
    <message>
        <source>Thai</source>
        <translation>Tailandés</translation>
    </message>
    <message>
        <source>Lao</source>
        <translation>Lao</translation>
    </message>
    <message>
        <source>Tibetan</source>
        <translation>Tibetano</translation>
    </message>
    <message>
        <source>Myanmar</source>
        <translation>Birmano</translation>
    </message>
    <message>
        <source>Khmer</source>
        <translation>Khmer</translation>
    </message>
    <message>
        <source>Han</source>
        <translation>Han</translation>
    </message>
    <message>
        <source>Hiragana</source>
        <translation>Hiragana</translation>
    </message>
    <message>
        <source>Katakana</source>
        <translation>Katakana</translation>
    </message>
    <message>
        <source>Hangul</source>
        <translation>Hangul</translation>
    </message>
    <message>
        <source>Bopomofo</source>
        <translation>Bopomofo</translation>
    </message>
    <message>
        <source>Yi</source>
        <translation>Yi</translation>
    </message>
    <message>
        <source>Ethiopic</source>
        <translation>Etíope</translation>
    </message>
    <message>
        <source>Cherokee</source>
        <translation>Cherokee</translation>
    </message>
    <message>
        <source>Canadian Aboriginal</source>
        <translation>Aborigen canadiense</translation>
    </message>
    <message>
        <source>Mongolian</source>
        <translation>Mongol</translation>
    </message>
    <message>
        <source>Currency Symbols</source>
        <translation>Símbolos de moneda</translation>
    </message>
    <message>
        <source>Letterlike Symbols</source>
        <translation>Símbolos similares a letras</translation>
    </message>
    <message>
        <source>Number Forms</source>
        <translation>Forma de números</translation>
    </message>
    <message>
        <source>Mathematical Operators</source>
        <translation>Operadores matemáticos</translation>
    </message>
    <message>
        <source>Technical Symbols</source>
        <translation>Símbolos técnicos</translation>
    </message>
    <message>
        <source>Geometric Symbols</source>
        <translation>Símbolos Geométricos</translation>
    </message>
    <message>
        <source>Miscellaneous Symbols</source>
        <translation>Símbolos Varios</translation>
    </message>
    <message>
        <source>Enclosed and Square</source>
        <translation>Cercados y cuadrados</translation>
    </message>
    <message>
        <source>Braille</source>
        <translation>Braille</translation>
    </message>
    <message>
        <source>Unicode</source>
        <translation>Unicode</translation>
    </message>
</context>
<context>
    <name>QFontDialog</name>
    <message>
        <source>&amp;Font</source>
        <translation>&amp;Fuente</translation>
    </message>
    <message>
        <source>Font st&amp;yle</source>
        <translation>Est&amp;ilo de la fuente</translation>
    </message>
    <message>
        <source>&amp;Size</source>
        <translation>&amp;Tamaño</translation>
    </message>
    <message>
        <source>Effects</source>
        <translation>Efectos</translation>
    </message>
    <message>
        <source>Stri&amp;keout</source>
        <translation>Tac&amp;hado</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>S&amp;ubrayado</translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation>&amp;Color</translation>
    </message>
    <message>
        <source>Sample</source>
        <translation>Ejemplo</translation>
    </message>
    <message>
        <source>Scr&amp;ipt</source>
        <translation>Scr&amp;ipt</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Select Font</source>
        <translation>Seleccionar Fuente</translation>
    </message>
</context>
<context>
    <name>QFtp</name>
    <message>
        <source>Host %1 found</source>
        <translation>Anfitrión %1 encontrado</translation>
    </message>
    <message>
        <source>Host found</source>
        <translation>Anfitrión encontrado</translation>
    </message>
    <message>
        <source>Connected to host %1</source>
        <translation>Conectado con el anfitrión %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Conectado con el anfitrión</translation>
    </message>
    <message>
        <source>Connection to %1 closed</source>
        <translation>Conexión con %1 cerrada</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Conexión cerrada</translation>
    </message>
    <message>
        <source>Host %1 not found</source>
        <translation>Anfitrión %1 no encontrado</translation>
    </message>
    <message>
        <source>Connection refused to host %1</source>
        <translation>Conexión rechazada con el anfitrión %1</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Error desconocido</translation>
    </message>
    <message>
        <source>Connecting to host failed:
%1</source>
        <translation>Conexión con el anfitrión fallida:
%1</translation>
    </message>
    <message>
        <source>Login failed:
%1</source>
        <translation>Indentificación fallida:
%1</translation>
    </message>
    <message>
        <source>Listing directory failed:
%1</source>
        <translation>Listado de directorio fallido:
%1</translation>
    </message>
    <message>
        <source>Changing directory failed:
%1</source>
        <translation>Cambio de directorio fallido:
%1</translation>
    </message>
    <message>
        <source>Downloading file failed:
%1</source>
        <translation>Descarga del fichero fallida:
%1</translation>
    </message>
    <message>
        <source>Uploading file failed:
%1</source>
        <translation>Carga de fichero fallida:
%1</translation>
    </message>
    <message>
        <source>Removing file failed:
%1</source>
        <translation>Eliminación de fichero fallida:
%1</translation>
    </message>
    <message>
        <source>Creating directory failed:
%1</source>
        <translation>Creación de fichero fallida:
%1</translation>
    </message>
    <message>
        <source>Removing directory failed:
%1</source>
        <translation>Eliminación de fichero fallida:
%1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>No conectado</translation>
    </message>
    <message>
        <source>Connection refused for data connection</source>
        <translation>Conexión rechazada para conexión de datos</translation>
    </message>
</context>
<context>
    <name>QHeader</name>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
<context>
    <name>QHttp</name>
    <message>
        <source>Connection refused</source>
        <translation>Conexión rechazada</translation>
    </message>
    <message>
        <source>Host %1 not found</source>
        <translation>Anfitrión %1 no encontrado</translation>
    </message>
    <message>
        <source>Wrong content length</source>
        <translation>Longitud del contenido errónea</translation>
    </message>
    <message>
        <source>HTTP request failed</source>
        <translation>Solicitud HTTP fallida</translation>
    </message>
    <message>
        <source>Host %1 found</source>
        <translation>Anfitrión %1 encontrado</translation>
    </message>
    <message>
        <source>Host found</source>
        <translation>Anfitrión encontrado</translation>
    </message>
    <message>
        <source>Connected to host %1</source>
        <translation>Conectado con el anfitrión %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Conectado con el anfitrión</translation>
    </message>
    <message>
        <source>Connection to %1 closed</source>
        <translation>Conexión con %1 cerrada</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Conexión cerrada</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Error desconocido</translation>
    </message>
    <message>
        <source>Request aborted</source>
        <translation>Solicitud abandonada</translation>
    </message>
    <message>
        <source>No server set to connect to</source>
        <translation>Servidor con el que conectar no especificado</translation>
    </message>
    <message>
        <source>Server closed connection unexpectedly</source>
        <translation>El servidor cerró la conexión inesperadamente</translation>
    </message>
    <message>
        <source>Invalid HTTP response header</source>
        <translation>Cabecera de respuesta HTTP no válida</translation>
    </message>
    <message>
        <source>Invalid HTTP chunked body</source>
        <translation>Fragmento HTTP no válido</translation>
    </message>
</context>
<context>
    <name>QInputDialog</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Deshacer</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Rehacer</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Cor&amp;tar</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Pegar</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleccionar todo</translation>
    </message>
</context>
<context>
    <name>QLocalFs</name>
    <message>
        <source>Could not rename
%1
to
%2</source>
        <translation>Imposible renombrar
%1
a
%2</translation>
    </message>
    <message>
        <source>Could not open
%1</source>
        <translation>Imposible abrir
%1</translation>
    </message>
    <message>
        <source>Could not write
%1</source>
        <translation>Imposible escribir
%1</translation>
    </message>
    <message>
        <source>Could not read directory
%1</source>
        <translation>Imposible leer directorio
%1</translation>
    </message>
    <message>
        <source>Could not create directory
%1</source>
        <translation>Imposible crear directorio
%1</translation>
    </message>
    <message>
        <source>Could not remove file or directory
%1</source>
        <translation>Imposible borrar fichero o directorio
%1</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Line up</source>
        <translation>Alinear</translation>
    </message>
    <message>
        <source>Customize...</source>
        <translation>Personalizar...</translation>
    </message>
</context>
<context>
    <name>QMenuBar</name>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>Config</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <source>Preference</source>
        <translation>Preferencia</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>Setting</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Setup</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Abandonar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Sí</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <source>&amp;Abort</source>
        <translation>&amp;Abandonar</translation>
    </message>
    <message>
        <source>&amp;Retry</source>
        <translation>&amp;Reintentar</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignorar</translation>
    </message>
    <message>
        <source>&lt;h3&gt;About Qt&lt;/h3&gt;&lt;p&gt;This program uses TQt version %1.&lt;/p&gt;&lt;p&gt;Qt is a C++ toolkit for multiplatform GUI &amp;amp; application development.&lt;/p&gt;&lt;p&gt;Qt provides single-source portability across MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux, and all major commercial Unix variants.&lt;br&gt;Qt is also available for embedded devices.&lt;/p&gt;&lt;p&gt;Qt is a Trolltech product. See &lt;tt&gt;https://trinitydesktop.org/docs/qt3/&lt;/tt&gt; for more information.&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Acerca de Qt&lt;/h3&gt;&lt;p&gt;Este programa usa TQt versión %1.&lt;/p&gt;&lt;p&gt;Qt es un conjunto de herramientas en C++ para el desarrollo de aplicaciones e interfaces gráficas de usuario (GUI) multiplataforma.&lt;/p&gt;&lt;p&gt;Qt proporciona portabilidad a nivel de código fuente entre MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux y las variantes comerciales de Unix más importantes.&lt;br&gt;Qt también está disponible para dispositivos empotrados.&lt;/p&gt;&lt;p&gt;Qt es un producto Trolltech. Vea &lt;tt&gt;https://trinitydesktop.org/docs/qt3/&lt;/tt&gt; para más información.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>QNetworkProtocol</name>
    <message>
        <source>Operation stopped by the user</source>
        <translation>Operación parada por el usuario</translation>
    </message>
</context>
<context>
    <name>QPrintDialog</name>
    <message>
        <source>locally connected</source>
        <translation>Conectada localmente</translation>
    </message>
    <message>
        <source>Aliases: %1</source>
        <translation>Alias: %1</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>desconocido</translation>
    </message>
    <message>
        <source>Unknown Location</source>
        <translation>Ubicación desconocida</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Printer settings</source>
        <translation>Ajustes de impresión</translation>
    </message>
    <message>
        <source>Print in color if available</source>
        <translation>Imprimir en color si disponible</translation>
    </message>
    <message>
        <source>Print in grayscale</source>
        <translation>Imprimir en tonos grises</translation>
    </message>
    <message>
        <source>Print destination</source>
        <translation>Destino de la impresión</translation>
    </message>
    <message>
        <source>Print to printer:</source>
        <translation>Imprimir en impresora:</translation>
    </message>
    <message>
        <source>Printer</source>
        <translation>Impresora</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Anfitrión</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Observaciones</translation>
    </message>
    <message>
        <source>Print to file:</source>
        <translation>Imprimir en fichero:</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Examinar...</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>Print all</source>
        <translation>Imprimir todo</translation>
    </message>
    <message>
        <source>Print range</source>
        <translation>Imprimir intervalo</translation>
    </message>
    <message>
        <source>From page:</source>
        <translation>Desde la página:</translation>
    </message>
    <message>
        <source>To page:</source>
        <translation>Hasta la página:</translation>
    </message>
    <message>
        <source>Print first page first</source>
        <translation>Imprimir primero la primera página</translation>
    </message>
    <message>
        <source>Print last page first</source>
        <translation>Imprimir primero la última página</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Número de copias:</translation>
    </message>
    <message>
        <source>Paper format</source>
        <translation>Formato del papel</translation>
    </message>
    <message>
        <source>Portrait</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <source>Landscape</source>
        <translation>Apaisado</translation>
    </message>
    <message>
        <source>A0 (841 x 1189 mm)</source>
        <translation>A0 (841 x 1189 mm)</translation>
    </message>
    <message>
        <source>A1 (594 x 841 mm)</source>
        <translation>A1 (594 x 841 mm)</translation>
    </message>
    <message>
        <source>A2 (420 x 594 mm)</source>
        <translation>A2 (420 x 594 mm)</translation>
    </message>
    <message>
        <source>A3 (297 x 420 mm)</source>
        <translation>A3 (297 x 420 mm)</translation>
    </message>
    <message>
        <source>A4 (210x297 mm, 8.26x11.7 inches)</source>
        <translation>A4 (210x297 mm, 8.26x11.7 inches)</translation>
    </message>
    <message>
        <source>A5 (148 x 210 mm)</source>
        <translation>A5 (148 x 210 mm)</translation>
    </message>
    <message>
        <source>A6 (105 x 148 mm)</source>
        <translation>A6 (105 x 148 mm)</translation>
    </message>
    <message>
        <source>A7 (74 x 105 mm)</source>
        <translation>A7 (74 x 105 mm)</translation>
    </message>
    <message>
        <source>A8 (52 x 74 mm)</source>
        <translation>A8 (52 x 74 mm)</translation>
    </message>
    <message>
        <source>A9 (37 x 52 mm)</source>
        <translation>A9 (37 x 52 mm)</translation>
    </message>
    <message>
        <source>B0 (1000 x 1414 mm)</source>
        <translation>B0 (1000 x 1414 mm)</translation>
    </message>
    <message>
        <source>B1 (707 x 1000 mm)</source>
        <translation>B1 (707 x 1000 mm)</translation>
    </message>
    <message>
        <source>B2 (500 x 707 mm)</source>
        <translation>B2 (500 x 707 mm)</translation>
    </message>
    <message>
        <source>B3 (353 x 500 mm)</source>
        <translation>B3 (353 x 500 mm)</translation>
    </message>
    <message>
        <source>B4 (250 x 353 mm)</source>
        <translation>B4 (250 x 353 mm)</translation>
    </message>
    <message>
        <source>B5 (176 x 250 mm, 6.93x9.84 inches)</source>
        <translation>B5 (176 x 250 mm, 6.93x9.84 inches)</translation>
    </message>
    <message>
        <source>B6 (125 x 176 mm)</source>
        <translation>B6 (125 x 176 mm)</translation>
    </message>
    <message>
        <source>B7 (88 x 125 mm)</source>
        <translation>B7 (88 x 125 mm)</translation>
    </message>
    <message>
        <source>B8 (62 x 88 mm)</source>
        <translation>B8 (62 x 88 mm)</translation>
    </message>
    <message>
        <source>B9 (44 x 62 mm)</source>
        <translation>B9 (44 x 62 mm)</translation>
    </message>
    <message>
        <source>B10 (31 x 44 mm)</source>
        <translation>B10 (31 x 44 mm)</translation>
    </message>
    <message>
        <source>C5E (163 x 229 mm)</source>
        <translation>C5E (163 x 229 mm)</translation>
    </message>
    <message>
        <source>DLE (110 x 220 mm)</source>
        <translation>DLE (110 x 220 mm)</translation>
    </message>
    <message>
        <source>Executive (7.5x10 inches, 191x254 mm)</source>
        <translation>Executive (7.5x10 inches, 191x254 mm)</translation>
    </message>
    <message>
        <source>Folio (210 x 330 mm)</source>
        <translation>Folio (210 x 330 mm)</translation>
    </message>
    <message>
        <source>Ledger (432 x 279 mm)</source>
        <translation>Ledger (432 x 279 mm)</translation>
    </message>
    <message>
        <source>Legal (8.5x14 inches, 216x356 mm)</source>
        <translation>Legal (8.5x14 inches, 216x356 mm)</translation>
    </message>
    <message>
        <source>Letter (8.5x11 inches, 216x279 mm)</source>
        <translation>Letter (8.5x11 inches, 216x279 mm)</translation>
    </message>
    <message>
        <source>Tabloid (279 x 432 mm)</source>
        <translation>Tabloid (279 x 432 mm)</translation>
    </message>
    <message>
        <source>US Common #10 Envelope (105 x 241 mm)</source>
        <translation>US Common #10 Envelope (105 x 241 mm)</translation>
    </message>
    <message>
        <source>Setup Printer</source>
        <translation>Configurar impresora</translation>
    </message>
    <message>
        <source>PostScript Files (*.ps);;All Files (*)</source>
        <translation>Fichero PostScript (*.ps);;Todos los ficheros (*)</translation>
    </message>
</context>
<context>
    <name>QProgressDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>QRegExp</name>
    <message>
        <source>no error occurred</source>
        <translation>Sin errores</translation>
    </message>
    <message>
        <source>disabled feature used</source>
        <translation>Se ha usado una característica no habilitada</translation>
    </message>
    <message>
        <source>bad char class syntax</source>
        <translation>Error de sintaxis en la clase de caracteres</translation>
    </message>
    <message>
        <source>bad lookahead syntax</source>
        <translation>Error de sintaxis en la ojeada</translation>
    </message>
    <message>
        <source>bad repetition syntax</source>
        <translation>Error de sintaxis en la repetición</translation>
    </message>
    <message>
        <source>invalid octal value</source>
        <translation>Valor octal no válido</translation>
    </message>
    <message>
        <source>missing left delim</source>
        <translation>Falta el delim iztquierdo</translation>
    </message>
    <message>
        <source>unexpected end</source>
        <translation>Fin inesperado</translation>
    </message>
    <message>
        <source>met internal limit</source>
        <translation>Se alcanzó el límite interno</translation>
    </message>
</context>
<context>
    <name>QSql</name>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Delete this record?</source>
        <translation>¿Borrar este registro?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insertar</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>Save edits?</source>
        <translation>¿Guardar cambios?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Cancel your edits?</source>
        <translation>¿Cancelar los cambios?</translation>
    </message>
</context>
<context>
    <name>QTabDialog</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>Valores por defecto</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>QTextEdit</name>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Deshacer</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Rehacer</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Cor&amp;tar</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Pegar</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleccionar todo</translation>
    </message>
</context>
<context>
    <name>QTitleBar</name>
    <message>
        <source>System Menu</source>
        <translation>Menú sistema</translation>
    </message>
    <message>
        <source>Shade</source>
        <translation>Oscurecer</translation>
    </message>
    <message>
        <source>Unshade</source>
        <translation>Desoscurecer</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizar</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimizar</translation>
    </message>
    <message>
        <source>Maximize</source>
        <translation>Maximizar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
</context>
<context>
    <name>QToolBar</name>
    <message>
        <source>More...</source>
        <translation>Más...</translation>
    </message>
</context>
<context>
    <name>QUrlOperator</name>
    <message>
        <source>The protocol `%1&apos; is not supported</source>
        <translation>El protocolo &apos;%1&apos; no está contemplado</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support listing directories</source>
        <translation>El protocolo &apos;%1&apos; no admite el listado de directorios</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support creating new directories</source>
        <translation>El protocolo &apos;%1&apos; no admite la creación de nuevos directorios</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support removing files or directories</source>
        <translation>El protocolo &apos;%1&apos; no admite el borrado de ficheros o directorios</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support renaming files or directories</source>
        <translation>El protocolo &apos;%1&apos; no admite el renombrado de ficheros o directorios</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support getting files</source>
        <translation>El protocolo &apos;%1&apos; no admite obtener ficheros</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support putting files</source>
        <translation>El protocolo &apos;%1&apos; no admite poner ficheros</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support copying or moving files or directories</source>
        <translation>El protocolo &apos;%1&apos; no admite la copia o relocalización de ficheros o directorios</translation>
    </message>
    <message>
        <source>(unknown)</source>
        <translation>(desconocido)</translation>
    </message>
</context>
<context>
    <name>QWSDecoration</name>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Restaurar</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Mover</translation>
    </message>
    <message>
        <source>&amp;Size</source>
        <translation>&amp;Tamaño</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimizar</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximizar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>KDE</source>
        <translation>KDE</translation>
    </message>
    <message>
        <source>KDE2</source>
        <translation>KDE2</translation>
    </message>
    <message>
        <source>BeOS</source>
        <translation>BeOS</translation>
    </message>
    <message>
        <source>Hydro</source>
        <translation>Hydro</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Valor por defecto</translation>
    </message>
</context>
<context>
    <name>QWhatsThisButton</name>
    <message>
        <source>What&apos;s this?</source>
        <translation>¿Qué es ésto?</translation>
    </message>
</context>
<context>
    <name>QWizard</name>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>&lt; &amp;Back</source>
        <translation>&lt; &amp;Atrás</translation>
    </message>
    <message>
        <source>&amp;Next &gt;</source>
        <translation>Siguie&amp;nte &gt;</translation>
    </message>
    <message>
        <source>&amp;Finish</source>
        <translation>&amp;Terminar</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ay&amp;uda</translation>
    </message>
</context>
<context>
    <name>QWorkspace</name>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Restaurar</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Mover</translation>
    </message>
    <message>
        <source>&amp;Size</source>
        <translation>&amp;Tamaño</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimizar</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximizar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>Stay on &amp;Top</source>
        <translation>Permanecer &amp;encima</translation>
    </message>
    <message>
        <source>Sh&amp;ade</source>
        <translation>&amp;Oscurecer</translation>
    </message>
    <message>
        <source>%1 - [%2]</source>
        <translation>%1 - [%2]</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimizar</translation>
    </message>
    <message>
        <source>Restore Down</source>
        <translation>Restaurar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>&amp;Unshade</source>
        <translation>&amp;Desoscurecer</translation>
    </message>
</context>
<context>
    <name>QXml</name>
    <message>
        <source>no error occurred</source>
        <translation>Sin errores</translation>
    </message>
    <message>
        <source>error triggered by consumer</source>
        <translation>error disparado por el consumidor</translation>
    </message>
    <message>
        <source>unexpected end of file</source>
        <translation>fin de fichero inesperado</translation>
    </message>
    <message>
        <source>more than one document type definition</source>
        <translation>más de una definición de tipo de documento</translation>
    </message>
    <message>
        <source>error occurred while parsing element</source>
        <translation>error al analizar elemento</translation>
    </message>
    <message>
        <source>tag mismatch</source>
        <translation>tag discordante</translation>
    </message>
    <message>
        <source>error occurred while parsing content</source>
        <translation>error al analizar contenido</translation>
    </message>
    <message>
        <source>unexpected character</source>
        <translation>carácter inesperado</translation>
    </message>
    <message>
        <source>invalid name for processing instruction</source>
        <translation>nombre para procesar la instrucción no válido</translation>
    </message>
    <message>
        <source>version expected while reading the XML declaration</source>
        <translation>se esperaba la versión al leer la declaración XML</translation>
    </message>
    <message>
        <source>wrong value for standalone declaration</source>
        <translation>valor erróneo para la declaración &apos;standalone&apos;</translation>
    </message>
    <message>
        <source>encoding declaration or standalone declaration expected while reading the XML declaration</source>
        <translation>se esperaba la declaración &apos;encoding&apos; o &apos;standalone&apos; al leer la declaración XML</translation>
    </message>
    <message>
        <source>standalone declaration expected while reading the XML declaration</source>
        <translation>se esperaba la declaración &apos;standalone&apos; al leer la declaración XML</translation>
    </message>
    <message>
        <source>error occurred while parsing document type definition</source>
        <translation>error al analizar la definición de tipo de documento</translation>
    </message>
    <message>
        <source>letter is expected</source>
        <translation>se esperaba una letra</translation>
    </message>
    <message>
        <source>error occurred while parsing comment</source>
        <translation>error al analizar comentario</translation>
    </message>
    <message>
        <source>error occurred while parsing reference</source>
        <translation>error al analizar referencia</translation>
    </message>
    <message>
        <source>internal general entity reference not allowed in DTD</source>
        <translation>no se permiten referencias internas a entidades generales en la DTD</translation>
    </message>
    <message>
        <source>external parsed general entity reference not allowed in attribute value</source>
        <translation>no se permiten referencias externas a entidades generales ya analizadas en el valor del atributo</translation>
    </message>
    <message>
        <source>external parsed general entity reference not allowed in DTD</source>
        <translation>no se permiten referencias externas a entidadades generales ya analizadas en la DTD</translation>
    </message>
    <message>
        <source>unparsed entity reference in wrong context</source>
        <translation>referencia a entidad no analizada en un contexto inadecuado</translation>
    </message>
    <message>
        <source>recursive entities</source>
        <translation>entidades recursivas</translation>
    </message>
    <message>
        <source>error in the text declaration of an external entity</source>
        <translation>error en la declaración textual de una entidad externa</translation>
    </message>
</context>
<context>
    <name>QtMultiLineEdit</name>
    <message>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Rehacer</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <source>Paste special...</source>
        <translation>Pegar especial...</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleccionar todo</translation>
    </message>
</context>
</TS>
